==> dde-launcher_4.4.5.5.orig.tar.xz: dde-launcher-4.4.5.5/translations/dde-launcher_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl" version="2.1">
<context>
    <name>AppsManager</name>
    <message>
        <source>No search results</source>
        <translation>Brak wyników wyszukiwania</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Chat</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Music</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Video</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Graphics</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Game</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Office</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reading</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Development</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>System</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Others</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FullScreenFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation>Czy na pewno chcesz odinstalować %1?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Potwierdź</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Remove from desktop</source>
        <translation>Usuń z pulpitu</translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation>Usuń z doku</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>Odinstaluj</translation>
    </message>
    <message>
        <source>Open by proxy</source>
        <translation>Otwórz przez pośrednik</translation>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation>Włącz skalowanie ekranu</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Otwórz</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation>Wyślij na pulpit</translation>
    </message>
    <message>
        <source>Send to dock</source>
        <translation>Zadokuj</translation>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation>Usuń z uruchamiania</translation>
    </message>
    <message>
        <source>Add to startup</source>
        <translation>Dodaj do uruchamiania</translation>
    </message>
</context>
<context>
    <name>MiniCategoryWidget</name>
    <message>
        <source>All Apps</source>
        <translation>Wszystkie programy</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Rozmowy</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Muzyka</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Filmy</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Grafika</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Gra</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Biuro</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Czytanie</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Programowanie</translation>
    </message>
    <message>
        <source>System</source>
        <translation>System</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>Inne</translation>
    </message>
</context>
<context>
    <name>MiniFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation>Czy na pewno chcesz odinstalować %1?</translation>
    </message>
    <message>
        <source>All dependencies will be removed together</source>
        <translation>Wszystkie zależności zostaną łącznie usunięte</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Potwierdź</translation>
    </message>
</context>
<context>
    <name>MiniFrameBottomBar</name>
    <message>
        <source>Computer</source>
        <translation>Komputer</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Dokumenty</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Filmy</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Muzyka</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Obrazy</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Pobrane</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Zablokuj</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Wylogowanie</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Uruchom ponownie</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Wstrzymaj</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Wyłącz</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Wstecz</translation>
    </message>
</context>
<context>
    <name>MiniFrameNavigation</name>
    <message>
        <source>Computer</source>
        <translation>Komputer</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Muzyka</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Wyłącz</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Zablokuj</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Wylogowanie</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Uruchom ponownie</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Wstrzymaj</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Wstecz</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Dokumenty</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Filmy</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Obrazy</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Pobrane</translation>
    </message>
</context>
<context>
    <name>MiniFrameRightBar</name>
    <message>
        <source>Computer</source>
        <translation>Komputer</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Muzyka</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Pobrane</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Ręcznie</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ustawienia</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Wyłącz</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Filmy</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Obrazy</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Dokumenty</translation>
    </message>
</context>
<context>
    <name>MiniFrameSwitchBtn</name>
    <message>
        <source>All Categories</source>
        <translation>Wszystkie kategorie</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Wstecz</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Szukaj</translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation>Czy na pewno chcesz odinstalować %1?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Potwierdź</translation>
    </message>
</context>
</TS>

==> dde-launcher_4.6.13.orig.tar.xz: dde-launcher-4.6.13/translations/dde-launcher_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl" version="2.1">
<context>
    <name>AppsManager</name>
    <message>
        <source>No search results</source>
        <translation>Brak wyników wyszukiwania</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Rozmowy</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Muzyka</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Filmy</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Grafika</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Biurowe</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Czytanie</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Programowanie</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Systemowe</translation>
    </message>
    <message>
        <source>Games</source>
        <translation>Gry</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Inne</translation>
    </message>
</context>
<context>
    <name>FullScreenFrame</name>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Potwierdź</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall %1 ?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Remove from desktop</source>
        <translation>Usuń z pulpitu</translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation>Usuń z doku</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>Odinstaluj</translation>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation>Wyłącz skalowanie ekranu</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Otwórz</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation>Wyślij na pulpit</translation>
    </message>
    <message>
        <source>Send to dock</source>
        <translation>Zadokuj</translation>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation>Usuń z uruchamiania</translation>
    </message>
    <message>
        <source>Add to startup</source>
        <translation>Dodaj do uruchamiania</translation>
    </message>
    <message>
        <source>Use a proxy</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniCategoryWidget</name>
    <message>
        <source>All Apps</source>
        <translation>Wszystkie programy</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Rozmowy</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Muzyka</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Filmy</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Grafika</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Gra</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Biuro</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Czytanie</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Programowanie</translation>
    </message>
    <message>
        <source>System</source>
        <translation>System</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>Inne</translation>
    </message>
</context>
<context>
    <name>MiniFrameBottomBar</name>
    <message>
        <source>Computer</source>
        <translation>Komputer</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Dokumenty</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Filmy</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Muzyka</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Obrazy</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Pobrane</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Zablokuj</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Wylogowanie</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Uruchom ponownie</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Wstrzymaj</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Wyłącz</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Wstecz</translation>
    </message>
</context>
<context>
    <name>MiniFrameNavigation</name>
    <message>
        <source>Computer</source>
        <translation>Komputer</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Muzyka</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Wyłącz</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Zablokuj</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Wylogowanie</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Uruchom ponownie</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Wstrzymaj</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Wstecz</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Dokumenty</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Filmy</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Obrazy</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Pobrane</translation>
    </message>
</context>
<context>
    <name>MiniFrameRightBar</name>
    <message>
        <source>Computer</source>
        <translation>Komputer</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Muzyka</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Pobrane</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Instrukcja Deepin</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ustawienia</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Filmy</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Obrazy</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Dokumenty</translation>
    </message>
    <message>
        <source>Power</source>
        <translation>Zasilanie</translation>
    </message>
</context>
<context>
    <name>MiniFrameSwitchBtn</name>
    <message>
        <source>All Categories</source>
        <translation>Wszystkie kategorie</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Wstecz</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Szukaj</translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Potwierdź</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall %1 ?</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
